@@ -22,9 +22,13 @@ from concurrent import futures
 import boto3
 import botocore
 import pathspec
-import progressbar
 
 with warnings.catch_warnings():
+    try:
+        import progressbar
+    except ImportError:  # pragma: no cover
+        progressbar = None
+
     try:
         import pync
     except Exception:  # pragma: no cover
@@ -32,7 +36,7 @@ with warnings.catch_warnings():
         # unsupported platforms
         pync = False
 
-VERSION = "3.0.1"
+VERSION = "3.0.3"
 VALID_ACLS = [
     "private",
     "public-read",
@@ -258,10 +262,17 @@ def upload_file(
                 extra_args["ContentType"] = f"{mimetype[0]};charset={charset}"
             elif mimetype[0]:
                 extra_args["ContentType"] = mimetype[0]
+            cache_timeout = None
             if mimetype[0] in caches.keys():
-                extra_args[
-                    "CacheControl"
-                ] = f"max-age={caches.get(mimetype[0])}, public"
+                cache_timeout = caches.get(mimetype[0])
+            elif mimetype[0] and f"{mimetype[0].split('/')[0]}/*" in caches.keys():
+                cache_timeout = caches.get(f"{mimetype[0].split('/')[0]}/*")
+            if cache_timeout is not None:
+                if cache_timeout == 0:
+                    extra_args["CacheControl"] = f"max-age={cache_timeout}, private"
+                else:
+                    extra_args["CacheControl"] = f"max-age={cache_timeout}, public"
+
             s3.meta.client.upload_fileobj(
                 local_file, bucket_name, key_name, ExtraArgs=extra_args,
             )
